@@ -6,7 +6,7 @@ from typing import (
     Generator, Dict, Union, Optional, Mapping, Any, Type, Tuple, List
 )
 from sqlalchemy import (
-    Table, Column, and_, select, insert, update, delete, func, nullslast
+    Table, Column, and_, select, insert, update, delete, func, nullslast, or_
 )
 from sqlalchemy.ext.asyncio import AsyncSession, async_scoped_session
 from sqlalchemy.orm import DeclarativeMeta
@@ -43,6 +43,7 @@ class AlchemyFilters(ABC):
     IN_OPERATOR = 'in'
     NOT_IN_OPERATOR = 'not_in'
     ALL_OBJECTS_FILTER = '__all__'
+    OR_LOOKUP = '__or__'
 
     LOOKUP_OPERATORS = MappingProxyType({
         EQUAL_OPERATOR:
@@ -170,30 +171,45 @@ class AlchemyFilters(ABC):
 
     def build_where_clause(
         self,
+        use_or: bool = False,
         reference_name: Optional[str] = None,
         **filters: Dict[str, Any]
     ) -> BinaryExpression:
         """
         """
-        expressions = []
+        expressions: List[BinaryExpression] = []
         for lookup, value in filters.items():
-            if type(value) == dict:
-                self_method = getattr(self, lookup, None)
-                if self_method is not None:
-                    e = self_method(value)
-                else:
-                    e = self.build_where_clause(
-                        reference_name=lookup,
-                        **value
-                    )
-            else:
-                e = self._build_expression(
-                    lookup=lookup,
-                    value=value,
-                    reference_name=reference_name
-                )
+            self_method = getattr(self, lookup, None)
+            if self_method is not None:
+                expression = self_method(value)
+                expressions.append(expression)
+                continue
 
-            expressions.append(e)
+            if lookup == self.OR_LOOKUP:
+                expression = self.build_where_clause(
+                    use_or=True,
+                    **value
+                )
+                expressions.append(expression)
+                continue
+
+            if type(value) == dict:
+                expression = self.build_where_clause(
+                    reference_name=lookup,
+                    **value
+                )
+                expressions.append(expression)
+                continue
+
+            expression = self._build_expression(
+                lookup=lookup,
+                value=value,
+                reference_name=reference_name
+            )
+            expressions.append(expression)
+
+        if use_or:
+            return or_(*expressions)
 
         return and_(*expressions)
 
@@ -276,7 +292,7 @@ class BaseAlchemyModelProvider(ABC):
     def _get_first_pk_column_name(self) -> str:
         """
         If self._first_pk_column_name is not defined
-        searches in mapper pk columns, 
+        searches in mapper pk columns,
         sets to self._first_pk_column_name that column name and
         returns first of the columns name, e.g. id column name
         else returns self._first_pk_column_name
@@ -357,7 +373,7 @@ class BaseAlchemyModelProvider(ABC):
             if type(order_reversed) == bool:
                 by_column = by_column.desc() \
                     if order_reversed else by_column.asc()
-            
+
             select_stmt = select_stmt.order_by(nullslast(by_column))
 
         if type(limit) == int:
@@ -377,7 +393,7 @@ class BaseAlchemyModelProvider(ABC):
         **filters
     ) -> Select:
         """
-        Builds select statement by passed filters 
+        Builds select statement by passed filters
         and return instance of Select class
         """
         filters = clear_from_ellipsis(**filters)
